@@ -14,24 +14,29 @@ _T = TypeVar("_T", bound=AlphaConfigSchema)
 
 
 def create_config_settings(
+    path: Path,
     model: Type[_T],
     environment_alias: str = "ALPHA_ENV",
-    config_dir_alias: str = "ALPHA_CONFIG_DIR",
+    root_alias: str = "ALPHA_ROOT",
+    port_alias: str = "ALPHA_PORT",
+    workers_alias: str = "ALPHA_WORKERS",
 ):
     class AlphaConfigSettingsSchema(BaseSettings):
         environment: str = Field(validation_alias=environment_alias)
-        config_dir: str = Field(validation_alias=config_dir_alias)
+        root: str = Field(validation_alias=root_alias)
+        port: int = Field(validation_alias=port_alias)
+        workers: int = Field(validation_alias=workers_alias)
 
         @computed_field
         @property
         def main_config(self) -> _T:
-            config_file_path = Path(self.config_dir) / f"config.{self.environment}.json"
-
-            data = open_json_file(path=config_file_path)
+            data = open_json_file(path=Path(path))
 
             data_ext = {
                 "environment": self.environment,
-                "config_file_path": config_file_path,
+                "root": self.root,
+                "port": self.port,
+                "workers": self.workers,
             }
 
             data.update(data_ext)
